--[[
LuCI - Lua Configuration Interface

Copyright 2008 Steven Barth <steven@midlink.org>
Copyright 2008 Jo-Philipp Wich <xm@leipzig.freifunk.net>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0
]]--

local m, s, o
local md = require "luci.model.modem"

m = Map("iottw")

s = m:section(NamedSection, "thingworx", "iottw", translate("ThingWorx"))
s.addremove = false

o = s:option(Flag, "enabled", translate("Enable"), translate("Enable ThingWorx Application"))
o.default = "0"

o = s:option(Value, "server", translate("Server Address"), translate("ThingWorx Server IP"))
o.rmempty = false
o.datatype = "host"

o = s:option(Value, "port", translate("Server Port"), translate("ThingWorx Server Port"))
o.datatype = "port"
o.rmempty = false

o = s:option(Value, "thing", translate("Thing Name"), translate("Thing name defined in ThingWorx CP"))
o.rmempty = false
o.maxlength = "32"

function o.validate(self, value)
	if not value or value:match("%W") then
		return nil, "Thing Name: \'" .. (value and value or "") .. "\' is invalid. Only alphanumeric"
			.. " characters are allowed."
	end
	return value
end

o = s:option(Value, "appkey", translate("Application Key"), translate("Application key generated in ThingWorx CP"))
o.rmempty = false
o.maxlength = "128"
o.datatype = "fieldvalidation('^[a-zA-Z0-9_-]+$', 0)"

function o.validate(self, value)
	if not value or value:gsub("-", ""):match("%W") then
		return nil, "Application Key: \'" .. (value and value or "") .. "\' is invalid. Only alphanumeric"
			.. " characters and '-' symbol are allowed."
	end
	return value
end

o = s:option(ListValue, "iface", translate("Mobile Interface"), translate("Interface name for which gsm values would be selected"))

local modems = false
local modem_list = md:get_all_modems()

function modem_match(modem_list, id)
	for _,v in pairs(modem_list) do
		if v.id == id then
			return true
		end
	end
	return false
end

m.uci:foreach("network", "interface", function(s)
	if s.modem and modem_match(modem_list, s.modem) then
		o:value(s[".name"])
		modems = true
	end
end)

if not modems then
	o:value("", translate("No Modem Connected"))
end

function o.write(self, section, value)
	local modem = m.uci:get("network", value, "modem")
	m.uci:set(self.config, section, "modem", modem)
	m.uci:set(self.config, section, "iface", value)
end

return m
